@@ -4,7 +4,7 @@ use warnings;
 package Dist::Zilla::PluginBundle::DAGOLDEN;
 # ABSTRACT: Dist::Zilla configuration the way DAGOLDEN does it
 
-our $VERSION = '0.073';
+our $VERSION = '0.074';
 
 # Dependencies
 use Moose 0.99;
@@ -383,7 +383,10 @@ sub configure {
         ),
         (
             $self->no_git ? ()
-            : [ 'Git::Check' => { allow_dirty => undef } ]
+            : [
+                'Git::Check' =>
+                  { allow_dirty => [ $self->auto_version ? 'cpanfile' : 'Makefile.PL' ] }
+            ]
         ),
         'CheckMetaResources',
         'CheckPrereqsIndexed',
@@ -402,7 +405,15 @@ sub configure {
         (
             $self->no_git
             ? ()
-            : ( [ 'Git::Tag' => { tag_format => $self->tag_format } ], )
+            : (
+                [
+                    'Git::Commit' => 'Commit_Dirty_Files' => {
+                        commit_msg => "Update " . ( $self->auto_version ? 'cpanfile' : 'Makefile.PL' ),
+                        allow_dirty => [ $self->auto_version ? 'cpanfile' : 'Makefile.PL' ]
+                    }
+                ],
+                [ 'Git::Tag' => { tag_format => $self->tag_format } ],
+            )
         ),
 
         # bumps Changes
@@ -439,7 +450,7 @@ __PACKAGE__->meta->make_immutable;
 #
 # This file is part of Dist-Zilla-PluginBundle-DAGOLDEN
 #
-# This software is Copyright (c) 2014 by David Golden.
+# This software is Copyright (c) 2015 by David Golden.
 #
 # This is free software, licensed under:
 #
@@ -458,7 +469,7 @@ Dist::Zilla::PluginBundle::DAGOLDEN - Dist::Zilla configuration the way DAGOLDEN
 
 =head1 VERSION
 
-version 0.073
+version 0.074
 
 =head1 SYNOPSIS
 
@@ -758,7 +769,7 @@ David Golden <dagolden@cpan.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Christian Walde Eric Johnson Karen Etheridge Philippe Bruhat (BooK) Sergey Romanov
+=for stopwords Christian Walde Eric Johnson Karen Etheridge Philippe Bruhat (BooK) Sergey Romanov 김도형 - Keedi Kim
 
 =over 4
 
@@ -782,11 +793,15 @@ Philippe Bruhat (BooK) <book@cpan.org>
 
 Sergey Romanov <complefor@rambler.ru>
 
+=item *
+
+김도형 - Keedi Kim <keedi@cpan.org>
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by David Golden.
+This software is Copyright (c) 2015 by David Golden.
 
 This is free software, licensed under:
 
